﻿init python:
    import pygame
    import random
    import time
    random.seed(time.perf_counter_ns())
    def distance(x, y):
        if x >= y:
            result = x - y
        else:
            result = y - x
        return result
    class money_wheel_bar(renpy.Displayable):
        def __init__(self):
            super(renpy.Displayable,self).__init__()
            self.image = "money_wheel_pointer"
            self.y = 0
            self.y_direction = 8
            self.moving = False
        def render(self,width,height,st,at):
            if self.y > 200:
                self.y_direction = -8
            elif self.y < -200:
                self.y_direction = 8
            if self.moving:
                self.y += self.y_direction

            t = Transform(self.image, xanchor=0.5, yanchor=0.5)
            child_render = renpy.render(t, width, height, st, at)
            cw, ch = child_render.get_size()

            rv = renpy.Render(cw, ch)
            rv.blit(child_render, (0, self.y))

            renpy.redraw(self, 0)
            return rv

    class money_wheel(renpy.Displayable):
        def __init__(self, image):
            super(renpy.Displayable,self).__init__()
            self.image = image
            self.x = 0
            self.y = 0
            self.rotation = 10
            self.visible = True
            self.parent = None
            self.rotation_velocity = 0
            self.spinning = False
        def spin(self, bar):
            self.spinning = True
            self.rotation_velocity = bar
            if bar > 0:
                self.spin_direction = 1
            else:
                self.spin_direction = -1
        def adjust(self, v):
            self.rotation += v
        def stop(self):
            self.spinning = False
            s = self.rotation % 360
            s += 360
            s = self.rotation % 360
            self.rotation = s
            self.parent.test += 1
            self.parent.check()
            renpy.restart_interaction()
        def render(self,width,height,st,at):
            if self.visible:
                if abs(self.rotation_velocity) > 0:
                    self.rotation += self.rotation_velocity/10
                    self.rotation_velocity -= self.spin_direction
                elif self.spinning:
                    self.stop()

                t = Transform(self.image, xanchor=0.5, yanchor=0.5, rotate = self.rotation)
                child_render = renpy.render(t, width, height, st, at)
                cw, ch = child_render.get_size()

                rv = renpy.Render(cw, ch)
                rv.blit(child_render, (0, 0))

                renpy.redraw(self, 0)
                return rv
            else:
                return renpy.Render(0,0)
    class money_wheel_manager:
        def __init__(self):
            self.points = [
                800,400,50,
                1,300,40,
                2,700,80,
                5,100,20,
                900,500,60,
                "jackpot",200,30,
                1000,600,70,
                0,90,10,
            ]
            self.wheel = money_wheel("money_wheel_wheel")
            self.wheel.parent = self
            self.bar = money_wheel_bar()
            self.test = 0
            self.jackpot = 0
            self.price = 100
            self.cash = 1000
            self.bet = 0
        def spin(self):
            if self.bar.moving:
                bar = self.bar.y
                self.bar.moving = False
                if abs(bar) > 50:
                    self.wheel.spin(bar)
                    renpy.play("money wheel/button.ogg", "sound")
                else:
                    renpy.play("money wheel/body.ogg", "sound")
        def check(self):
            i = int(self.wheel.rotation / 15)
            win = self.points[i]
            if win == "jackpot":
                self.cash += self.jackpot * self.bet
                floating_text(self.jackpot * self.bet, 0,0)
                self.jackpot = 0
                renpy.play("money wheel/payout.ogg", "sound")
            else:
                floating_text(win * self.bet, 0,0)
                if win:
                    renpy.play("money wheel/cash_register.ogg", "sound")
                self.cash += win * self.bet
            self.bet = 0
        def pay(self):
            if self.cash >= self.price:
                floating_text(-self.price, 700,0)
                renpy.play("money wheel/coin.ogg", "sound")
                self.bar.moving = True
                self.jackpot += self.price // 2
                self.cash -= self.price
                self.bet += 1

transform wheel_button:
    on hover:
        ease .4 xoffset 10
    on idle:
        ease .4 xoffset 0
screen money_wheel():
    modal True
    default g = money_wheel_manager()
    style_prefix "money_wheel"
    fixed:
        xysize 1920,1080
        vbox:
            align .9,.5
            button:
                at wheel_button
                xysize 218,88
                background "wheel_button_1"
                text "Pay"
                action Function(g.pay)
            button:
                at wheel_button
                xysize 218,88
                background "wheel_button_2"
                text "Spin"
                action Function(g.spin)
        add "money_wheel_stand"
        frame:
            align .5,.5 xysize 300,500 xoffset -476 background None
            has vbox
            align .5,.5
            frame:
                background Frame("wheel_frame", 10,10)
                padding 20,20 xsize 300 yalign .0
                has vbox
                align .0,.5
                text "Jackpot"
                text f"{g.jackpot}"
            frame:
                background Frame("wheel_frame", 10,10)
                padding 20,20 xsize 300 yalign .5
                has vbox
                align .0,.5
                text "Your cash"
                text f"{g.cash}"
            frame:
                background Frame("wheel_frame", 10,10)
                padding 20,20 xsize 300 yalign 1.0
                has vbox
                align .0,.5
                text "Your bet"
                text f"{g.bet}x"
        align .5,.5
        add g.wheel align .5,.5
        add "money_wheel_cover" align .5,.5
        frame:
            xoffset 500
            align .5,.5 xysize 40,440 padding 2,0
            background None
            frame:
                background "#f009" ysize 100 align .5,.5
            add g.bar align .5,.5 xoffset 30

            



    # vbox:
    #     text str(g.cash)
    #     text str(g.wheel.rotation)
    #     text str(g.test)
    #     button:
    #         text "up"
    #         action Function(g.wheel.adjust, 1)
    #     button:
    #         text "down"
    #         action Function(g.wheel.adjust, -1)

style money_wheel_text:
    align (.5,.5)
    color "#ffa200"
style money_wheel_button:
    background "#fff9"
    padding (10,10)
    size_group "wheel"

label money_wheel_example:
    show bg with dissolve
    call screen money_wheel